@@ -370,16 +370,7 @@ if(missing(parscale)) parscale <- 1
   ##########################################################################################################################
 
 
-e.v <- round(min(eigen(SemiParFit$fit$hessian, symmetric=TRUE, only.values = TRUE)$values), 6)
-gradi <- round(max(abs(SemiParFit$fit$gradient)),1)
-
-me1 <- "Largest absolute gradient value is not close to 0."
-me2 <- "Information matrix is not positive definite."
-me3 <- "Read the WARNINGS section in ?copulaSampleSel."
-
-if(gradi > 10 && e.v < 0){ warning(me1, call. = FALSE); warning(paste(me2,"\n",me3), call. = FALSE)} 
-if(gradi > 10 && e.v > 0)   warning(paste(me1,"\n",me3), call. = FALSE)
-if(gradi < 10 && e.v < 0)  warning(paste(me2,"\n",me3), call. = FALSE)
+cov.c(SemiParFit)
 
   ##########################################################################################################################
 gam1$call$data <- gam2$call$data <- gam3$call$data <- gam4$call$data <- gam5$call$data <- gam6$call$data <- gam7$call$data <- gam8$call$data <- cl$data 
@@ -441,7 +432,7 @@ L <- list(fit = SemiParFit$fit, dataset = dataset, formula = formula,
           l.flist = l.flist, v1 = v1, v2 = v2, triv = FALSE, univar.gamlss = FALSE, BivD2 = BivD2, dof = dof, dof.a = dof, call = cl,
           surv = FALSE, surv.flex = surv.flex)
 
-class(L) <- c("copulaSampleSel", "SemiParBIV")
+class(L) <- c("copulaSampleSel", "SemiParBIV","gjrm")
 
 L
 
