@@ -1,4 +1,4 @@
-pred.mvt <- function(x, eq, fun = "mean", n.sim = 100, prob.lev = 0.05, ...){
+pred.mvt <- function(x, eq, fun = "mean", n.sim = 100, prob.lev = 0.05, smooth.no = NULL, ...){
 
 
  if( !(fun %in% c("mean", "variance", "tau")) ) stop("The value for fun can either be mean, variance or tau.")
@@ -9,11 +9,12 @@ pred.mvt <- function(x, eq, fun = "mean", n.sim = 100, prob.lev = 0.05, ...){
  if(missing(eq)) stop("You must provide the equation number.")
  if(!(eq %in% c(1, 2))) stop("The value for eq can be either 1 or 2.")
 
- if(!(x$margins[1] %in% c(x$VC$m2, x$VC$m2d)) && !(x$margins[2] %in% c(x$VC$m2, x$VC$m2d)) ) stop("This is currently implemented for margins with two parameters.\nGet in touch to check progress on the other cases.") 
+ if(!(x$margins[1] %in% c(x$VC$m2, x$VC$m2d, x$VC$bl, x$VC$m1d)) && !(x$margins[2] %in% c(x$VC$m2, x$VC$m2d)) ) stop("This is currently implemented for margins with two parameters.\nGet in touch to check progress on the other cases.") 
 
  if(eq == 1) mar <- x$margins[1]
  if(eq == 2) mar <- x$margins[2] 
  
+ 
  bs <- rMVN(n.sim, mean = x$coefficients, sigma = x$Vb)
  
  
@@ -21,27 +22,62 @@ pred.mvt <- function(x, eq, fun = "mean", n.sim = 100, prob.lev = 0.05, ...){
 if( x$margins[1] %in% c(x$VC$m2, x$VC$m2d) && x$margins[2] %in% c(x$VC$m2, x$VC$m2d) ){ ###############
  
   
- if(eq == 1){ind1 <- (1:x$X1.d2); ind2 <- (x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2) } 
+ if(eq == 1){ind1 <- (1:x$X1.d2);                       ind2 <- (x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2) } 
  if(eq == 2){ind1 <- (x$X1.d2 + 1):(x$X1.d2 + x$X2.d2); ind2 <- (x$X1.d2 + x$X2.d2 + x$X3.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2 + x$X4.d2) }  
 
 if(eq == 1){
+
  Xfit1 <- predict(x, eq = 1, type = "lpmatrix", ...)
- Xfit2 <- predict(x, eq = 3, type = "lpmatrix", ...) 
  fit1  <- predict(x, eq = 1, type = "link", ...)
+ 
+ Xfit2 <- predict(x, eq = 3, type = "lpmatrix", ...) 
  fit2  <- predict(x, eq = 3, type = "link", ...) 
+ 
            }
 
 if(eq == 2){
+
  Xfit1 <- predict(x, eq = 2, type = "lpmatrix", ...)
- Xfit2 <- predict(x, eq = 4, type = "lpmatrix", ...) 
  fit1  <- predict(x, eq = 2, type = "link", ...)
+
+ Xfit2 <- predict(x, eq = 4, type = "lpmatrix", ...)  
  fit2  <- predict(x, eq = 4, type = "link", ...)  
+ 
            }
 
+
+if(!is.null(smooth.no)){
+
+
+if(eq == 1){
+
+Xfit1[, -c(x$gam1$smooth[[smooth.no]]$first.para:x$gam1$smooth[[smooth.no]]$last.para)] <- 0 
+Xfit2[, -c(x$gam3$smooth[[smooth.no]]$first.para:x$gam3$smooth[[smooth.no]]$last.para)] <- 0 
+
+           }
+
+if(eq == 2){
+
+Xfit1[, -c(x$gam2$smooth[[smooth.no]]$first.para:x$gam2$smooth[[smooth.no]]$last.para)] <- 0 
+Xfit2[, -c(x$gam4$smooth[[smooth.no]]$first.para:x$gam4$smooth[[smooth.no]]$last.para)] <- 0 
+
+           }
+
+fit1 <- Xfit1%*%x$coefficients[ind1]
+fit2 <- Xfit2%*%x$coefficients[ind2]
+
+}
+
+
+
+
 fit1Sim <- Xfit1%*%t(bs[, ind1])
 fit2Sim <- Xfit2%*%t(bs[, ind2])
 
 
+
+
+
 }############
 
 
@@ -51,7 +87,12 @@ if( x$margins[1] %in% c(x$VC$bl, x$VC$m1d) && x$margins[2] %in% c(x$VC$m2, x$VC$
  
   
  if(eq == 1){ind1 <- (1:x$X1.d2) } 
- if(eq == 2){ind1 <- (x$X1.d2 + 1):(x$X1.d2 + x$X2.d2); ind2 <- (x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2) }  
+ 
+ if(eq == 2){ind1 <- (x$X1.d2 + 1):(x$X1.d2 + x$X2.d2); 
+ 
+     if(is.null(x$X3)) ind2 <- x$X1.d2 + x$X2.d2 + 1 else ind2 <- (x$X1.d2 + x$X2.d2 + 1):(x$X1.d2 + x$X2.d2 + x$X3.d2) 
+             
+             }  
 
 if(eq == 1){
  Xfit1 <- predict(x, eq = 1, type = "lpmatrix", ...)
@@ -59,14 +100,35 @@ if(eq == 1){
            }
 
 if(eq == 2){
- Xfit1 <- predict(x, eq = 2, type = "lpmatrix", ...)
- Xfit2 <- predict(x, eq = 3, type = "lpmatrix", ...) 
- fit1  <- predict(x, eq = 2, type = "link", ...)
- fit2  <- predict(x, eq = 3, type = "link", ...)  
-           }
 
+
+ Xfit1 <- predict(x, eq = 2, type = "lpmatrix", ...)
+ fit1  <- predict(x, eq = 2, type = "link", ...)
+ 
+ if(!is.null(x$X3)){
+ 
+   Xfit2 <- predict(x, eq = 3, type = "lpmatrix", ...) 
+   fit2  <- predict(x, eq = 3, type = "link", ...)  
+   
+                   }
+ 
+ if(is.null(x$X3)){
+ 
+   Xfit2 <- matrix(1, nrow = length(fit1), ncol = 1) 
+   fit2  <- x$coefficients["sigma2.star"]
+   
+                   } 
+ 
+           }
+           
+           
 fit1Sim <- Xfit1%*%t(bs[, ind1])
-if(eq == 2) fit2Sim <- Xfit2%*%t(bs[, ind2])
+
+if(eq == 2){ 
+
+       if(!is.null(x$X3)) fit2Sim <- Xfit2%*%t(bs[, ind2]) else fit2Sim <- bs[, ind2]
+       
+           }
 
 
 }##################
@@ -103,7 +165,7 @@ if(eq == 2) fit2Sim <- Xfit2%*%t(bs[, ind2])
 
  if(mar %in% c("iG")){
  
-    if(fun == "mean")     {fit <- exp(fit1)^3;           fitSim <- exp(fit1Sim)^3              } 
+    if(fun == "mean")     {fit <- exp(fit1);             fitSim <- exp(fit1Sim)                } 
     if(fun == "variance") {fit <- exp(fit1)^3*exp(fit2); fitSim <- exp(fit1Sim)^3*exp(fit2Sim) }
                                     
  }  
